breed [states state]

globals [
 ; Npopulation ; fixed total population
 Ncontributor ; number of contributor
 Ndefector ; number of defectors
 Nmoralist ; number of D-punishing contributors
 Nimmoralist ; number of D-punishing defectors
 ; Nhyena ; number of C-punishing defectors
 totalpower ; total system capabilities
 ; altpower ; alternative hegemon relative capabilities
 totalcontribution ; total contributions per tick
 totalpunishment ; total punishments of defectors per tick
 TotalDpower ; total power of defectors per tick
 TotalPpower ; total power of punishers per tick
 ; totalCpunishment ; total puninishments for cooperators per tick
 ; contributionratio ; fixed contribution cost
 ; punishmentratio ; fixed punishment cost
 ; synergyratio ; fixed synergy factor
 ; tolerance ; How sensitive are states to proximate rolemodels?
 ; mutationrate ; Chance of strategy mutation
 ; resolutehegemon ; Does the hegemon always contribute and punish on tick 1?
 ; resolutechallenger ; Does the alternative hegemon always defect on tick 1?
 WinScore ; winning lifetime benefits
 WinCoop ; winning cooperation probability
 WinPunish ; winning punishment probability
 WinProp ; winning distance
 WinPower ; winning state power
 HegemonScore ; Hegemon's final score
 AltHegemonScore ; Alt Hegemon's final score
 meanpower ; mean of state power
 meancontribute ; mean of contribution scores
 meanDPunish ; mean of Dpunish scores
 ]

states-own [
  contribute ; probability that a state will contribute
  Dpunish ; probability that a state punishes defectors
  ; Cpunish ; probability that a state punishes cooperators
  power ; fixed state power
  propensity ; fixed geographical distance indicator
  DidCoop ; Did a state cooperate this tick?
  DidPunish ; Did a state punish this tick?
  benefit ; total per tick payoff
  benefitlifetime ; lifetime payoffs
  ; pgrowth ; growth rate of power per tick
    ]

to setup
  clear-all
  create-states Npopulation
  set totalpower 0

  ask states [
    set power random-float altpower
    set totalpower totalpower + power
    set xcor random 10
    set propensity xcor
    set contribute random-float 1
    set Dpunish random-float 1
    ; set pgrowth 1
  ]

  ; Modifies the hegemon
  ask state 0 [
    set totalpower Totalpower - power
    set power 1
    set totalpower Totalpower + power
    set xcor 10
    set propensity xcor
    if resolutehegemon = true
    [set contribute 1
    set Dpunish 1]
  ]

  ; Modifies the althegemon
  ask state 1 [
    set totalpower Totalpower - power
    set power altpower
    set totalpower Totalpower + power
    set xcor 0
    set propensity xcor
    if resolutechallenger = true
    [set contribute 0
    set DPunish 0]
  ]

  set meanpower (mean [power] of states)
  reset-ticks
end

to setup-europe
  clear-all
  set Npopulation 19
  create-states Npopulation
  set totalpower 0
  let powerlist [1 0.923 1.6029 0.6621 0.3766 0.3312 0.1923 0.1818 0.1308 0.1265 0.0953 0.0747 0.0656 0.0502 0.049 0.0428 0.0407 0.0321 0.032]
  let propensitylist [4 0 7 7 8 5 4 4 4 2 4 2 10 4 10 4 4 4 7]
  ; let growthlist [1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1]

ask states [
    let n (who)
    set power (item n powerlist)
    set totalpower (totalpower + power)
    ; set pgrowth (item n growthlist)
    set xcor (item n propensitylist)
    set propensity xcor
    set contribute random-float 1
    set Dpunish random-float 1
  ]

   ; Modifies the hegemon
   if resolutehegemon = true [
   ask state 0 [
    set contribute 1
    set Dpunish 1
  ]]

  ; Modifies the althegemon
  if resolutechallenger = true [
  ask state 1 [
    set contribute 0
    set DPunish 0
  ]]

 set meanpower (mean [power] of states)
 reset-ticks

end

to setup-asia
  clear-all
  set Npopulation 17
  create-states Npopulation
  set totalpower 0
  let powerlist [1 0.9289 0.3828 0.2793 0.2129 0.1444 0.1042 0.0628 0.0572 0.041 0.038 0.0295 0.0209 0.0166 0.0089 0.0028 0.0022]
  let propensitylist [10 0 5 4 6 8 3 10 5 6 6 3 3 3 10 4 2]
  ; let growthlist [1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1]

ask states [
    let n (who)
    set power (item n powerlist)
    set totalpower (totalpower + power)
    ; set pgrowth (item n growthlist)
    set xcor (item n propensitylist)
    set propensity xcor
    set contribute random-float 1
    set Dpunish random-float 1
  ]

  ; Modifies the hegemon
  if resolutehegemon = true [
  ask state 0 [
    set contribute 1
    set Dpunish 1
  ]]

  ; Modifies the althegemon
  if resolutechallenger = true [
  ask state 1 [
    set contribute 0
    set DPunish 0
    ]]

  set meanpower (mean [power] of states)
  reset-ticks
end

to go
  calfitness
  imitation
  mutation
  if ticks > 500 [stop]
  tick
end

to calfitness
; calculation of the payoffs when agents made decisions on cooperation and punishment.
 set Ncontributor 0
 set Ndefector 0
 set Nmoralist 0
 set Nimmoralist 0
 set WinScore -10000
 ; set Nhyena 0
 set totalcontribution 0
 set totalpunishment 0
 set TotalDpower 0
 set TotalPpower 0
 ; set TotalCpunishment 0

 ; calls states and rolls for contribution and defection
 ask states [
    ; set power power * (pgrowth)
    facexy -1 0
    rt (cos(180 * contribute) * -90)
    set DidCoop 0
    set DidPunish 0
    ifelse random-float 1 < contribute
      [set DidCoop 1
      set Ncontributor (Ncontributor + 1)
      set totalcontribution (totalcontribution + (power * contributionratio))]
      [set Ndefector (Ndefector + 1)
      set TotalDpower (TotalDpower + power)]
    if random-float 1 < Dpunish
      [set DidPunish 1
      set totalpunishment (totalpunishment + (power * punishmentratio))
      set TotalPpower (TotalPpower + power)]
    if DidCoop = 1 and DidPunish = 1
    [set Nmoralist (Nmoralist + 1)]
    if DidCoop = 0 and DidPunish = 1
    [set Nimmoralist (Nimmoralist + 1)]
  ]

  ; distributes costs and benefits, grows state power if applicable
   ask states [
      set benefit 0
      set benefit ((power / totalpower) * totalcontribution) * synergyratio
      ifelse DidCoop = 1
      [set benefit (benefit - (power * contributionratio))]
      [set benefit (benefit - (power * (Nmoralist + Nimmoralist) * punishmentratio))]
      if DidPunish = 1
      [set benefit (benefit - (TotalDpower * punishmentratio))]
      set benefitlifetime (benefitlifetime + benefit)
       ]

  ; End of Turn Summary Statistics
  let Winner max-one-of states [benefitlifetime / power]
  set WinScore ([benefitlifetime / power] of Winner)
  set WinCoop ([contribute] of Winner)
  set WinPunish ([DPunish] of Winner)
  set WinProp ([propensity] of Winner)
  set WinPower ([power] of Winner)
  set HegemonScore [benefitlifetime / power] of state 0
  set AltHegemonScore [benefitlifetime / power] of state 1
  set meancontribute (mean [contribute] of states)
  set meanDPunish (mean [DPunish] of states)
end

to imitation
; calculates new strategies of agents as a consequence of imitation of local winners (localities defined by tolerance)
  ask states [
    let LocalWinner max-one-of states in-radius tolerance [benefitlifetime / power]
    let LocalWinScore ([benefitlifetime / power] of LocalWinner)
    let LocalWinDidCoop ([DidCoop] of LocalWinner)
    let LocalWinDidPunish ([DidPunish] of LocalWinner)
    if (benefitlifetime / power) <= localwinscore [
       set contribute (contribute - ((random-normal 0.1 0.025) * (contribute - LocalWinDidCoop)))
       set DPunish (Dpunish - ((random-normal 0.1 0.025) * (DPunish - LocalWinDidPunish)))
      ]
     ]

end

to mutation
  ask states [
    if (random-float 1 <= mutationrate) [
      ifelse DidCoop = 0 [set contribute 1][set contribute 0]
      ifelse Didpunish = 0 [set Dpunish 1][set Dpunish 0]
    ]
   ]

end
@#$#@#$#@
GRAPHICS-WINDOW
241
10
689
59
-1
-1
40.0
1
8
1
1
1
0
0
0
1
0
10
0
0
1
1
0
ticks
24.0

BUTTON
15
10
102
58
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
105
10
179
58
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
431
324
845
575
Punishment Scores
Ticks
DPunishment %
0.0
501.0
0.0
1.0
false
false
"" ""
PENS
"pen-0" 1.0 0 -13840069 true "" "ask state 0 [plot Dpunish]"
"pen-1" 1.0 0 -2674135 true "" "ask state 1 [plot DPunish]"
"pen-2" 1.0 0 -16777216 true "" "ask state 2 [plot DPunish]"
"pen-3" 1.0 0 -16777216 true "" "ask state 4 [plot DPunish]"
"pen-4" 1.0 0 -16777216 true "" "ask state 5 [plot DPunish]"
"pen-5" 1.0 0 -16777216 true "" "ask state 6 [plot DPunish]"
"pen-6" 1.0 0 -16777216 true "" "ask state 7 [plot DPunish]"
"pen-7" 1.0 0 -16777216 true "" "ask state 8 [plot DPunish]"
"pen-8" 1.0 0 -16777216 true "" "ask state 9 [plot DPunish]"
"pen-9" 1.0 0 -16777216 true "" "ask state 10 [plot DPunish]"
"pen-10" 1.0 0 -16777216 true "" "ask state 11 [plot DPunish]"
"pen-11" 1.0 0 -16777216 true "" "ask state 12 [plot DPunish]"
"pen-12" 1.0 0 -16777216 true "" "ask state 13 [plot DPunish]"
"pen-13" 1.0 0 -16777216 true "" "ask state 14 [plot DPunish]"
"pen-14" 1.0 0 -16777216 true "" "ask state 15 [plot DPunish]"
"pen-15" 1.0 0 -16777216 true "" "ask state 16 [plot DPunish]"
"pen-16" 1.0 0 -16777216 true "" "ask state 17 [plot DPunish]"
"pen-17" 1.0 0 -16777216 true "" "ask state 2 [plot DPunish]"
"pen-18" 1.0 0 -16777216 true "" "ask state 3 [plot Dpunish]"

PLOT
12
325
421
576
Contribution Scores
Ticks
Contribution %
0.0
501.0
0.0
1.0
false
false
"" ""
PENS
"pen-0" 1.0 0 -16777216 true "" "ask state 2 [plot contribute]"
"pen-1" 1.0 0 -13840069 true "" "ask state 0 [plot contribute]"
"pen-2" 1.0 0 -5298144 true "" "ask state 1 [plot contribute]"
"pen-3" 1.0 0 -16777216 true "" "ask state 3 [plot contribute]"
"pen-4" 1.0 0 -16777216 true "" "ask state 4 [plot contribute]"
"pen-5" 1.0 0 -16777216 true "" "ask state 5 [plot contribute]"
"pen-6" 1.0 0 -16777216 true "" "ask state 6 [plot contribute]"
"pen-7" 1.0 0 -16777216 true "" "ask state 7 [plot contribute]"
"pen-8" 1.0 0 -16777216 true "" "ask state 8 [plot contribute]"
"pen-9" 1.0 0 -16777216 true "" "ask state 9 [plot contribute]"
"pen-10" 1.0 0 -16777216 true "" "ask state 10 [plot contribute]"
"pen-11" 1.0 0 -16777216 true "" "ask state 11 [plot contribute]"
"pen-12" 1.0 0 -16777216 true "" "ask state 12 [plot contribute]"
"pen-13" 1.0 0 -16777216 true "" "ask state 13 [plot contribute]"
"pen-14" 1.0 0 -16777216 true "" "ask state 14 [plot contribute]"
"pen-15" 1.0 0 -16777216 true "" "ask state 15 [plot contribute]"
"pen-16" 1.0 0 -16777216 true "" "ask state 16 [plot contribute]"
"pen-17" 1.0 0 -16777216 true "" "ask state 17 [plot contribute]"

SLIDER
12
66
184
99
Npopulation
Npopulation
0
50
18.0
1
1
NIL
HORIZONTAL

SLIDER
13
144
185
177
punishmentratio
punishmentratio
0
1
0.5
0.1
1
NIL
HORIZONTAL

SLIDER
12
104
184
137
contributionratio
contributionratio
0
1
1.0
0.01
1
NIL
HORIZONTAL

SLIDER
13
183
185
216
synergyratio
synergyratio
0
5
1.0
0.5
1
NIL
HORIZONTAL

PLOT
189
56
568
324
Counts
Ticks
Number
0.0
501.0
0.0
18.0
false
true
"" ""
PENS
"Contributors" 1.0 0 -13840069 true "" "plot Ncontributor"
"Defectors" 1.0 0 -5298144 true "" "plot Ndefector"
"Moralists" 1.0 0 -14454117 true "" "plot Nmoralist"
"Immoralists" 1.0 0 -7171555 true "" "plot Nimmoralist"

PLOT
568
56
944
324
Performance
States
Lifetimebenefits/power
0.0
18.0
-1.5
1.5
false
false
"" ""
PENS
"default" 1.0 1 -12087248 true "" "clear-plot\nplot-pen-up\nplotxy -1 0 \nplot-pen-down\nask state 0 [plot benefit]"
"pen-1" 1.0 1 -8053223 true "" "plot-pen-up\nplotxy 0 0 \nplot-pen-down\nask state 1 [plot benefit]\n"
"pen-2" 1.0 1 -7500403 true "" "plot-pen-up\nplotxy 1 0 \nplot-pen-down\nask state 2 [plot benefit]"
"pen-3" 1.0 1 -2674135 true "" "plot-pen-up\nplotxy 2 0 \nplot-pen-down\nask state 3 [plot benefit]"
"pen-4" 1.0 1 -955883 true "" "plot-pen-up\nplotxy 3 0 \nplot-pen-down\nask state 4 [plot benefit]"
"pen-5" 1.0 1 -6459832 true "" "plot-pen-up\nplotxy 4 0 \nplot-pen-down\nask state 5 [plot benefit]"
"pen-6" 1.0 1 -1184463 true "" "plot-pen-up\nplotxy 5 0 \nplot-pen-down\nask state 6 [plot benefit]"
"pen-7" 1.0 1 -10899396 true "" "plot-pen-up\nplotxy 6 0 \nplot-pen-down\nask state 7 [plot benefit]"
"pen-8" 1.0 1 -13840069 true "" "plot-pen-up\nplotxy 7 0 \nplot-pen-down\nask state 8 [plot benefit]"
"pen-9" 1.0 1 -14835848 true "" "plot-pen-up\nplotxy 8 0 \nplot-pen-down\nask state 9 [plot benefit]"
"pen-10" 1.0 1 -11221820 true "" "plot-pen-up\nplotxy 9 0 \nplot-pen-down\nask state 10 [plot benefit]"
"pen-11" 1.0 1 -13791810 true "" "plot-pen-up\nplotxy 10 0 \nplot-pen-down\nask state 11 [plot benefit]"
"pen-12" 1.0 1 -13345367 true "" "plot-pen-up\nplotxy 11 0 \nplot-pen-down\nask state 12 [plot benefit]"
"pen-13" 1.0 1 -8630108 true "" "plot-pen-up\nplotxy 12 0 \nplot-pen-down\nask state 13 [plot benefit]"
"pen-14" 1.0 1 -5825686 true "" "plot-pen-up\nplotxy 13 0 \nplot-pen-down\nask state 14 [plot benefit]"
"pen-15" 1.0 1 -2064490 true "" "plot-pen-up\nplotxy 14 0 \nplot-pen-down\nask state 15 [plot benefit]"
"pen-16" 1.0 1 -16777216 true "" "plot-pen-up\nplotxy 15 0 \nplot-pen-down\nask state 16 [plot benefit]"
"pen-17" 1.0 1 -16777216 true "" "plot-pen-up\nplotxy 16 0 \nplot-pen-down\nask state 17 [plot benefit]"
"pen-18" 1.0 1 -16777216 true "" "plot-pen-up\nplotxy 17 0 \nplot-pen-down\nask state 18 [plot benefit]"

SLIDER
13
219
185
252
altpower
altpower
0
1
0.9
0.05
1
NIL
HORIZONTAL

SLIDER
13
291
185
324
tolerance
tolerance
0
10
10.0
1
1
NIL
HORIZONTAL

SLIDER
13
254
186
287
mutationrate
mutationrate
0
0.02
0.0
0.005
1
NIL
HORIZONTAL

MONITOR
846
419
966
464
AltHegemon Score
[benefitlifetime / altpower] of state 1
17
1
11

MONITOR
845
326
964
371
Global HighScore
max [benefitlifetime / power] of states
17
1
11

MONITOR
847
372
966
417
Hegemon Score
[benefitlifetime] of state 0
17
1
11

BUTTON
691
13
808
55
Setup Europe 1933
setup-europe
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
811
13
944
56
Setup Asia 2013
setup-asia
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
847
466
985
499
ResoluteHegemon
ResoluteHegemon
1
1
-1000

SWITCH
846
501
985
534
ResoluteChallenger
ResoluteChallenger
1
1
-1000

@#$#@#$#@
This is a Netlogo implementation of the model described in Boyd, R., Gintis, H., Bowles, S. & Richerson, P. J. (2003) The evolution of altruistic punishment, Proceedings of the National Academy of Science of the United States of America 100(6): 3531-3535

The replication is performed by Marco A. Janssen, Arizona State University, August 2008. Copyright (C) 2008 M.A. Janssen

This program is free software; you can redistribute it and/or modify it under the   
terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version. This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

link
true
0
Line -7500403 true 150 0 150 300

link direction
true
0
Line -7500403 true 150 150 30 225
Line -7500403 true 150 150 270 225

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Experiment (m=0, r=1, ap=0.8, c=0.4) Baseline" repetitions="150" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="500"/>
    <metric>Ncontributor</metric>
    <metric>Ndefector</metric>
    <metric>Nmoralist</metric>
    <metric>Nimmoralist</metric>
    <metric>totalpower</metric>
    <metric>totalcontribution</metric>
    <metric>totalpunishment</metric>
    <metric>TotalDpower</metric>
    <metric>TotalPpower</metric>
    <metric>WinScore</metric>
    <metric>WinCoop</metric>
    <metric>WinPunish</metric>
    <metric>WinProp</metric>
    <metric>WinPower</metric>
    <metric>HegemonScore</metric>
    <metric>AltHegemonScore</metric>
    <metric>meanpower</metric>
    <metric>meancontribute</metric>
    <metric>meanDPunish</metric>
    <enumeratedValueSet variable="synergyratio">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="punishmentratio">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="altpower">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tolerance">
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
      <value value="8"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutationrate">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment (m=0, r=1.5, 2, ap=0.8, c=0.3) Synergy" repetitions="150" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="500"/>
    <metric>Ncontributor</metric>
    <metric>Ndefector</metric>
    <metric>Nmoralist</metric>
    <metric>Nimmoralist</metric>
    <metric>totalpower</metric>
    <metric>totalcontribution</metric>
    <metric>totalpunishment</metric>
    <metric>TotalDpower</metric>
    <metric>TotalPpower</metric>
    <metric>WinScore</metric>
    <metric>WinCoop</metric>
    <metric>WinPunish</metric>
    <metric>WinProp</metric>
    <metric>WinPower</metric>
    <metric>HegemonScore</metric>
    <metric>AltHegemonScore</metric>
    <metric>meanpower</metric>
    <metric>meancontribute</metric>
    <metric>meanDPunish</metric>
    <enumeratedValueSet variable="synergyratio">
      <value value="1.5"/>
      <value value="2"/>
      <value value="2.5"/>
      <value value="3"/>
      <value value="3.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="punishmentratio">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="altpower">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tolerance">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutationrate">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment (m=0, r=1, variable ap, c=0.3) Power" repetitions="150" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="500"/>
    <metric>Ncontributor</metric>
    <metric>Ndefector</metric>
    <metric>Nmoralist</metric>
    <metric>Nimmoralist</metric>
    <metric>totalpower</metric>
    <metric>totalcontribution</metric>
    <metric>totalpunishment</metric>
    <metric>TotalDpower</metric>
    <metric>TotalPpower</metric>
    <metric>WinScore</metric>
    <metric>WinCoop</metric>
    <metric>WinPunish</metric>
    <metric>WinProp</metric>
    <metric>WinPower</metric>
    <metric>HegemonScore</metric>
    <metric>AltHegemonScore</metric>
    <metric>meanpower</metric>
    <metric>meancontribute</metric>
    <metric>meanDPunish</metric>
    <enumeratedValueSet variable="synergyratio">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="punishmentratio">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="altpower">
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.9"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tolerance">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutationrate">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment (m=0.01, r=1, ap=0.8, c=0.4) Mutation" repetitions="150" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="500"/>
    <metric>Ncontributor</metric>
    <metric>Ndefector</metric>
    <metric>Nmoralist</metric>
    <metric>Nimmoralist</metric>
    <metric>totalpower</metric>
    <metric>totalcontribution</metric>
    <metric>totalpunishment</metric>
    <metric>TotalDpower</metric>
    <metric>TotalPpower</metric>
    <metric>WinScore</metric>
    <metric>WinCoop</metric>
    <metric>WinPunish</metric>
    <metric>WinProp</metric>
    <metric>WinPower</metric>
    <metric>HegemonScore</metric>
    <metric>AltHegemonScore</metric>
    <metric>meanpower</metric>
    <metric>meancontribute</metric>
    <metric>meanDPunish</metric>
    <enumeratedValueSet variable="synergyratio">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="punishmentratio">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="altpower">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tolerance">
      <value value="2"/>
      <value value="4"/>
      <value value="6"/>
      <value value="8"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutationrate">
      <value value="0.01"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment (Robustness Check) UnResoluteCH" repetitions="150" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="500"/>
    <metric>Ncontributor</metric>
    <metric>Ndefector</metric>
    <metric>Nmoralist</metric>
    <metric>Nimmoralist</metric>
    <metric>totalpower</metric>
    <metric>totalcontribution</metric>
    <metric>totalpunishment</metric>
    <metric>TotalDpower</metric>
    <metric>TotalPpower</metric>
    <metric>WinScore</metric>
    <metric>WinCoop</metric>
    <metric>WinPunish</metric>
    <metric>WinProp</metric>
    <metric>WinPower</metric>
    <metric>HegemonScore</metric>
    <metric>AltHegemonScore</metric>
    <metric>meanpower</metric>
    <metric>meancontribute</metric>
    <metric>meanDPunish</metric>
    <enumeratedValueSet variable="synergyratio">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="punishmentratio">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="altpower">
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
      <value value="0.9"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tolerance">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutationrate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resolutehegemon">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resolutechallenger">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment (m=0, r=1, ap=0.8, variable c) Punishment" repetitions="150" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="500"/>
    <metric>Ncontributor</metric>
    <metric>Ndefector</metric>
    <metric>Nmoralist</metric>
    <metric>Nimmoralist</metric>
    <metric>totalpower</metric>
    <metric>totalcontribution</metric>
    <metric>totalpunishment</metric>
    <metric>TotalDpower</metric>
    <metric>TotalPpower</metric>
    <metric>WinScore</metric>
    <metric>WinCoop</metric>
    <metric>WinPunish</metric>
    <metric>WinProp</metric>
    <metric>WinPower</metric>
    <metric>HegemonScore</metric>
    <metric>AltHegemonScore</metric>
    <metric>meanpower</metric>
    <metric>meancontribute</metric>
    <metric>meanDPunish</metric>
    <enumeratedValueSet variable="synergyratio">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="punishmentratio">
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="altpower">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tolerance">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutationrate">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment (m=0, r=1, variable ap, c=0.2) Power" repetitions="150" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="500"/>
    <metric>Ncontributor</metric>
    <metric>Ndefector</metric>
    <metric>Nmoralist</metric>
    <metric>Nimmoralist</metric>
    <metric>totalpower</metric>
    <metric>totalcontribution</metric>
    <metric>totalpunishment</metric>
    <metric>TotalDpower</metric>
    <metric>TotalPpower</metric>
    <metric>WinScore</metric>
    <metric>WinCoop</metric>
    <metric>WinPunish</metric>
    <metric>WinProp</metric>
    <metric>WinPower</metric>
    <metric>HegemonScore</metric>
    <metric>AltHegemonScore</metric>
    <metric>meanpower</metric>
    <metric>meancontribute</metric>
    <metric>meanDPunish</metric>
    <enumeratedValueSet variable="synergyratio">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="punishmentratio">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="altpower">
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.9"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tolerance">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutationrate">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment (m=0, r=1, variable ap, c=0.4) Power" repetitions="150" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="500"/>
    <metric>Ncontributor</metric>
    <metric>Ndefector</metric>
    <metric>Nmoralist</metric>
    <metric>Nimmoralist</metric>
    <metric>totalpower</metric>
    <metric>totalcontribution</metric>
    <metric>totalpunishment</metric>
    <metric>TotalDpower</metric>
    <metric>TotalPpower</metric>
    <metric>WinScore</metric>
    <metric>WinCoop</metric>
    <metric>WinPunish</metric>
    <metric>WinProp</metric>
    <metric>WinPower</metric>
    <metric>HegemonScore</metric>
    <metric>AltHegemonScore</metric>
    <metric>meanpower</metric>
    <metric>meancontribute</metric>
    <metric>meanDPunish</metric>
    <enumeratedValueSet variable="synergyratio">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="punishmentratio">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="altpower">
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.9"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tolerance">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutationrate">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment (Robustness Check) UnResoluteC" repetitions="150" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="500"/>
    <metric>Ncontributor</metric>
    <metric>Ndefector</metric>
    <metric>Nmoralist</metric>
    <metric>Nimmoralist</metric>
    <metric>totalpower</metric>
    <metric>totalcontribution</metric>
    <metric>totalpunishment</metric>
    <metric>TotalDpower</metric>
    <metric>TotalPpower</metric>
    <metric>WinScore</metric>
    <metric>WinCoop</metric>
    <metric>WinPunish</metric>
    <metric>WinProp</metric>
    <metric>WinPower</metric>
    <metric>HegemonScore</metric>
    <metric>AltHegemonScore</metric>
    <metric>meanpower</metric>
    <metric>meancontribute</metric>
    <metric>meanDPunish</metric>
    <enumeratedValueSet variable="synergyratio">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="punishmentratio">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="altpower">
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
      <value value="0.9"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tolerance">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutationrate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resolutehegemon">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resolutechallenger">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment (Robustness Check) UnResoluteH" repetitions="150" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="500"/>
    <metric>Ncontributor</metric>
    <metric>Ndefector</metric>
    <metric>Nmoralist</metric>
    <metric>Nimmoralist</metric>
    <metric>totalpower</metric>
    <metric>totalcontribution</metric>
    <metric>totalpunishment</metric>
    <metric>TotalDpower</metric>
    <metric>TotalPpower</metric>
    <metric>WinScore</metric>
    <metric>WinCoop</metric>
    <metric>WinPunish</metric>
    <metric>WinProp</metric>
    <metric>WinPower</metric>
    <metric>HegemonScore</metric>
    <metric>AltHegemonScore</metric>
    <metric>meanpower</metric>
    <metric>meancontribute</metric>
    <metric>meanDPunish</metric>
    <enumeratedValueSet variable="synergyratio">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="punishmentratio">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="altpower">
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
      <value value="0.9"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tolerance">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutationrate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resolutehegemon">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="resolutechallenger">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment Europe (m=0, r=1)" repetitions="200" runMetricsEveryStep="true">
    <setup>setup-europe</setup>
    <go>go</go>
    <timeLimit steps="500"/>
    <metric>Ncontributor</metric>
    <metric>Ndefector</metric>
    <metric>Nmoralist</metric>
    <metric>Nimmoralist</metric>
    <metric>totalpower</metric>
    <metric>totalcontribution</metric>
    <metric>totalpunishment</metric>
    <metric>TotalDpower</metric>
    <metric>TotalPpower</metric>
    <metric>WinScore</metric>
    <metric>WinCoop</metric>
    <metric>WinPunish</metric>
    <metric>WinProp</metric>
    <metric>WinPower</metric>
    <metric>HegemonScore</metric>
    <metric>AltHegemonScore</metric>
    <metric>meanpower</metric>
    <metric>meancontribute</metric>
    <metric>meanDPunish</metric>
    <enumeratedValueSet variable="synergyratio">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="punishmentratio">
      <value value="0.2"/>
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tolerance">
      <value value="2"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutationrate">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment Asia (m=0, r=1)" repetitions="200" runMetricsEveryStep="true">
    <setup>setup-asia</setup>
    <go>go</go>
    <timeLimit steps="500"/>
    <metric>Ncontributor</metric>
    <metric>Ndefector</metric>
    <metric>Nmoralist</metric>
    <metric>Nimmoralist</metric>
    <metric>totalpower</metric>
    <metric>totalcontribution</metric>
    <metric>totalpunishment</metric>
    <metric>TotalDpower</metric>
    <metric>TotalPpower</metric>
    <metric>WinScore</metric>
    <metric>WinCoop</metric>
    <metric>WinPunish</metric>
    <metric>WinProp</metric>
    <metric>WinPower</metric>
    <metric>HegemonScore</metric>
    <metric>AltHegemonScore</metric>
    <metric>meanpower</metric>
    <metric>meancontribute</metric>
    <metric>meanDPunish</metric>
    <enumeratedValueSet variable="synergyratio">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="punishmentratio">
      <value value="0.2"/>
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tolerance">
      <value value="2"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutationrate">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment Total" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="500"/>
    <metric>Ncontributor</metric>
    <metric>Nmoralist</metric>
    <enumeratedValueSet variable="synergyratio">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="punishmentratio">
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="altpower">
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tolerance">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ResoluteHegemon">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ResoluteChallenger">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutationrate">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
